
EXCLUDED_SOFTWARE_PROJECTS = [
    'Data',
    'pypi-sphinx-quickstart',
    'derobertis-cv',
    'Python',
    'Coins',
    '2017 Data Collection',
    'Code',
    'crypto-pricing',
    'dash_keyed_file_browser',
    'fin-model-course-projects',
    'awesome-panel',
    'awesome-panel-extensions',
]

PROFESSIONAL_SOFTWARE_PROJECT_ORDER = [
    'py-ex-latex',
    'data-code',
    'py-file-conf',
    'py-finstmt',
    'pysentiment',
    'regtools',
    'sensitivity',
    'fin-model-course',
    'py-research-workflows',
    'cryptocompare-py',

]

ACADEMIC_INCLUDED_SOFTWARE_PROJECTS = [
    'py-ex-latex',
    'cryptocompare-py',
    'capiq-excel-downloader-py',
    'datastream-excel-downloader-py',
    'py-edgar-api',
    'data-code',
    'regtools',
    'sensitivity',
    'py-finstmt',
    'pysentiment',
]